@@ -615,7 +615,6 @@ def station_interface(isa_yaml, grp_yaml, attr_yaml, rvxlen, pkg_name,
                     bsvstr +=(methoda_read_temp.format('Bit#('+str(size)
                             + ') _' + shadow_csr, shadow_csr))
                     incomming_reads.append(shadow_csr)
-
     if logging:
         logger.info('Interface created for : ' + pkg_name)
     # define generic methods for all stations
@@ -733,9 +732,18 @@ def station_methods(isa_yaml, grp_yaml, attr_yaml, rvxlen, pkg_name,
         if logging:
             logger.debug('-- Defining value methods for : ' + csrname)
         if attr_yaml[csrname]['value_method']['required']:
+            size = attr_yaml[csrname]['size']
             if 'dec_body' in attr_yaml[csrname]['value_method']:
-                for dec in attr_yaml[csrname]['value_method']['dec_body']:
-                    bsvstr += methodv_def_temp.format(csrname, '', dec)
+                for _str in attr_yaml[csrname]['value_method']['dec_body']:
+                    _str = _str.replace('size', str(size))
+                    _str = _str.replace('xlen', str(xlen))
+                    if '::' in _str:
+                        cond = _str.split('::')[0]
+                        if eval(cond):
+                            _str = _str.split('::')[1]
+                            bsvstr += methodv_def_temp.format(csrname, '', _str)
+                    else:
+                        bsvstr += methodv_def_temp.format(csrname,'',_str)
             else:
                 bsvstr += methodv_def_temp.format(csrname, 'rg_', csrname)
     
@@ -805,6 +813,21 @@ def station_methods(isa_yaml, grp_yaml, attr_yaml, rvxlen, pkg_name,
                     else:
                         bsvstr += temp_method_shadow.format(str(size), shadow_csr)
                     incomming_reads.append(shadow_csr)
+    req_ifc = []
+    for csrname in isa_yaml:
+        if csrname.lower() in attr_yaml and 'additional_method_body' in attr_yaml[csrname.lower()]:
+            for add_ifc in attr_yaml[csrname.lower()]['additional_method_body']:
+                if '::' in add_ifc:
+                    cond = add_ifc.split('::')[0]
+                    if cond:
+                        add_ifc = add_ifc.split('::')[1]
+                    else:
+                        add_ifc = ''
+                if add_ifc not in req_ifc:
+                    bsvstr +=\
+                        textwrap.indent(add_ifc, '    ') + '\n'
+                    req_ifc.append(add_ifc)
+
 
     bsvstr += method_generic_def_temp
     if not last:
